#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import sys
import os
from gettext import gettext as _

sys.path.append(os.path.join(os.path.dirname(__file__), ".."))

from gi import require_version
require_version("Gtk", "3.0")

from gi.repository import Gio
from gi.repository import Gtk
from gi.repository import Gdk
from gi.repository import GLib

from gasimporter.configuration import APP_NAMESPACE
from gasimporter.configuration import get_ui_dir
from gasimporter.window import ApplicationWindow

class Application(Gtk.Application):

    def __init__(self):
        Gtk.Application.__init__(self,
                                 application_id=APP_NAMESPACE,
                                 flags=Gio.ApplicationFlags.FLAGS_NONE)

        self.window = None

    def do_startup(self):
        Gtk.Application.do_startup(self)

        self.build_actions()
        self.build_menu()

    def do_activate(self):
        if self.window:
            return
        self.window = ApplicationWindow(self)
        #.show() vs. .present()
        #http://www.pygtk.org/pygtk2reference/class-gtkwindow.html#method-gtkwindow--present
        self.window.present()

    """
    Create acclerator actions for app-menu
    https://git.gnome.org/browse/gnome-music/tree/gnomemusic/application.py
    """
    def build_actions(self):
        actions = [
            ('preferences', self.preferences, ["<Control>p", "<Control>comma"]),
            ('help', self.help, ["F3"]),
            ('shortcuts', self.shortcuts, ["F2"]),
            ('about', self.about, ["F1"]),
            ('quit', self.quit, ["<Control>q"]),
        ]

        for action, callback, accelerators in actions:
            simpleAction = Gio.SimpleAction.new(action, None)
            simpleAction.connect('activate', callback)
            self.add_action(simpleAction)
            if accelerators:
                self.set_accels_for_action("app.{}".format(action), accelerators)
                #ShortcutsWindow.add_action("app.{}".format(action), _("Edit settings"))

    def build_menu(self):
        builder = Gtk.Builder()
        builder.add_from_file("{}/{}".format(get_ui_dir(), "app-menu.ui"))
        menu = builder.get_object("app-menu")

        self.set_app_menu(menu)

    def preferences(self, action, param):
        print ("Preferneces Launched")

    def help(self, action, param):
        Gtk.show_uri(None, "help:gas-importer", Gdk.CURRENT_TIME)

    def shortcuts(self, action, param):
        self.window.dialog_shortcuts()

    def about(self, action, param):
        self.window.dialog_about()

    def dialog_response(self, dialog, response):
        dialog.destroy()

    def quit(self, action=None, param=None):
        self.window.destroy()




    """
    Create acclerator actions for app-menu
    https://git.gnome.org/browse/gnome-music/tree/gnomemusic/application.py
    """
    def _create_actions(self):
        action = Gio.SimpleAction.new("preferences", None)
        action.connect("activate", self.on_preferences)
        self.add_action(action)
        self.set_accels_for_action("app.preferences", ["<Control>p"])
        #ShortcutsWindow.add_action("app.settings", _("Edit settings"))

        action = Gio.SimpleAction.new("about", None)
        action.connect("activate", self.on_about)
        self.add_action(action)
        self.set_accels_for_action("app.about", ["F3"])

        action = Gio.SimpleAction.new("shortcuts", None)
        action.connect("activate", self.on_shortcuts)
        self.add_action(action)
        self.set_accels_for_action("app.shortcuts", ["F2"])

        action = Gio.SimpleAction.new("help", None)
        action.connect("activate", self.on_help)
        self.add_action(action)
        self.set_accels_for_action("app.help", ["F1",
                                                "<Control>question"])

        action = Gio.SimpleAction.new("quit", None)
        action.connect("activate", self.on_quit)
        self.add_action(action)
        self.set_accels_for_action("app.quit", ["<Control>q"])

    def _create_app_menu(self):
        builder = Gtk.Builder()
        #builder.add_from_file("../data/ui/app-menu.ui")
        builder.add_from_file("{}/{}".format(get_ui_dir(), "app-menu.ui"))
        menu = builder.get_object("app-menu")

        self.set_app_menu(menu)

    def on_preferences(self, action, param):
        pass

    def on_about(self, action, param):
        self.window.dialog_about()
        #builder = Gtk.Builder()
        ##builder.add_from_file("../data/ui/about.ui")
        #builder.add_from_file("{}/{}".format(get_ui_dir(), "about.ui"))
        #dialog = builder.get_object("about_dialog")
        #dialog.set_transient_for(self.window)
        #dialog.show()

    def on_shortcuts(self, action, param):
        self.window.dialog_shortcuts()
        #builder = Gtk.Builder()
        ##builder.add_from_file("../data/ui/shortcuts.ui")
        #builder.add_from_file("{}/{}".format(get_ui_dir(), "shortcuts.ui"))
        #dialog = builder.get_object("shortcuts")
        #dialog.set_transient_for(self.window)
        #dialog.show()

    def on_help(self, action, param):
        pass

    def on_quit(self, action, param):
        self.quit()

if __name__ == "__main__":
    app = Application()
    app.run(sys.argv)
